==> glooxbindings-0.1.1.tar.bz2: glooxbindings-0.1.1/src/python/examples/consoleclient.py <==
# This sample will log in using the given JID
# it will print out any messages recieved
# to send a message, type the (full) JID of the receiver, hit enter
# the type the message text, hit enter. that's it.

import gloox
import sys
import select
import getpass

class MyClient( gloox.MessageHandler ):
  j = gloox.JID( sys.argv[1] )
  c = gloox.Client( j, '' )
  gloox_fd = 0
  input_fd = sys.stdin.fileno()
  b = False
  haveJid = False
  jid = gloox.JID()

  def __init__( self ):
    gloox.MessageHandler.__init__( self )

  def setPassword( self, pwd ):
    self.c.setPassword( pwd )

  def connect( self ):
    self.c.registerMessageHandler( self )
    self.b = self.c.connect( False )
    self.gloox_fd = self.c.fileDescriptor()

  def handleMessage( self, stanza ):
    print '---------'
    print 'Message from: ' + stanza._from().full()
    print stanza.body()
    print '---------'

  def run( self ):
    fds = [self.gloox_fd, self.input_fd]
    if self.b:
      print 'successfully connected'
      while self.b:
        r = select.select( fds, [], [], 0.01 )
        for fd in r[0]:
          if fd == self.gloox_fd:
            self.c.recv( -1 )
          else:
            txt = sys.stdin.readline()
            if self.haveJid:
              s = gloox.Stanza.createMessageStanza( self.jid, txt[:-1] )
              self.c.send( s )
              self.haveJid = False
            else:
              self.haveJid = True
              self.jid.setJID( txt )

t = MyClient()
pwd = getpass.getpass( 'Password for ' + sys.argv[1] + ': ' )
t.setPassword( pwd )
t.connect()
t.run()

==> glooxbindings-0.1.4.tar.bz2: glooxbindings-0.1.4/src/python/examples/consoleclient.py <==
# This sample will log in using the given JID
# it will print out any messages recieved
# to send a message, type the (full) JID of the receiver, hit enter
# the type the message text, hit enter. that's it.

import gloox
import sys
import select
import getpass

class MyClient( gloox.MessageHandler ):
  j = gloox.JID( sys.argv[1] )
  c = gloox.Client( j, '' )
  m_conn = gloox.ConnectionTCPClient( c, c.logInstance(), j.server() )
  c.setConnectionImpl( conn );
  gloox_fd = 0
  input_fd = sys.stdin.fileno()
  b = False
  haveJid = False
  jid = gloox.JID()

  def __init__( self ):
    gloox.MessageHandler.__init__( self )

  def setPassword( self, pwd ):
    self.c.setPassword( pwd )

  def connect( self ):
    self.c.registerMessageHandler( self )
    self.b = self.c.connect( False )
    self.gloox_fd = self.m_conn.socket()

  def handleMessage( self, stanza ):
    print '---------'
    print 'Message from: ' + stanza._from().full()
    print stanza.body()
    print '---------'

  def run( self ):
    fds = [self.gloox_fd, self.input_fd]
    if self.b:
      print 'successfully connected'
      while self.b:
        r = select.select( fds, [], [], 0.01 )
        for fd in r[0]:
          if fd == self.gloox_fd:
            self.c.recv( -1 )
          else:
            txt = sys.stdin.readline()
            if self.haveJid:
              s = gloox.Stanza.createMessageStanza( self.jid, txt[:-1] )
              self.c.send( s )
              self.haveJid = False
            else:
              self.haveJid = True
              self.jid.setJID( txt )

t = MyClient()
pwd = getpass.getpass( 'Password for ' + sys.argv[1] + ': ' )
t.setPassword( pwd )
t.connect()
t.run()
